* ChangeLog.2, ChangeLog.3, ChangeLog.4, ChangeLog.5, ChangeLog,
authorjsm28 <jsm28@138bc75d-0d04-0410-961f-82ee72b054a4>
Sun, 11 Nov 2001 11:25:28 +0000 (11:25 +0000)
committerjsm28 <jsm28@138bc75d-0d04-0410-961f-82ee72b054a4>
Sun, 11 Nov 2001 11:25:28 +0000 (11:25 +0000)
cfg.c, cfganal.c, cfgcleanup.c, cfglayout.c, cfgloop.c, cfgrtl.c,
collect2.c, combine.c, config.in, configure, configure.in,
conflict.c, dwarf2out.c, dwarfout.c, except.c, final.c, flow.c,
genattrtab.c, ggc-page.c, jump.c, lcm.c, predict.c, reg-stack.c,
reload1.c, rtlanal.c, sched-rgn.c, toplev.c, unwind-dw2-fde.h: Fix
spelling errors.

git-svn-id: svn+ssh://gcc.gnu.org/svn/gcc/trunk@46928 138bc75d-0d04-0410-961f-82ee72b054a4

33 files changed:
gcc/ChangeLog
gcc/ChangeLog.2
gcc/ChangeLog.3
gcc/ChangeLog.4
gcc/ChangeLog.5
gcc/cfg.c
gcc/cfganal.c
gcc/cfgcleanup.c
gcc/cfglayout.c
gcc/cfgloop.c
gcc/cfgrtl.c
gcc/collect2.c
gcc/combine.c
gcc/config.in
gcc/configure
gcc/configure.in
gcc/conflict.c
gcc/dwarf2out.c
gcc/dwarfout.c
gcc/except.c
gcc/final.c
gcc/flow.c
gcc/genattrtab.c
gcc/ggc-page.c
gcc/jump.c
gcc/lcm.c
gcc/predict.c
gcc/reg-stack.c
gcc/reload1.c
gcc/rtlanal.c
gcc/sched-rgn.c
gcc/toplev.c
gcc/unwind-dw2-fde.h

index 1b9e512..eb1a3fb 100644 (file)
@@ -1,3 +1,13 @@
+2001-11-11  Joseph S. Myers  <jsm28@cam.ac.uk>
+
+       * ChangeLog.2, ChangeLog.3, ChangeLog.4, ChangeLog.5, ChangeLog,
+       cfg.c, cfganal.c, cfgcleanup.c, cfglayout.c, cfgloop.c, cfgrtl.c,
+       collect2.c, combine.c, config.in, configure, configure.in,
+       conflict.c, dwarf2out.c, dwarfout.c, except.c, final.c, flow.c,
+       genattrtab.c, ggc-page.c, jump.c, lcm.c, predict.c, reg-stack.c,
+       reload1.c, rtlanal.c, sched-rgn.c, toplev.c, unwind-dw2-fde.h: Fix
+       spelling errors.
+
 Sun Nov 11 05:56:01 2001  Richard Kenner  <kenner@vlsi1.ultra.nyu.edu>
 
        * config/rs6000/rs6000.c (rs6000_hash_constant, toc_hash_eq):
@@ -927,8 +937,8 @@ Tue Nov  6 09:21:34 2001  Richard Kenner  <kenner@vlsi1.ultra.nyu.edu>
 
 Mon Nov  5 16:15:25 CET 2001  Jan Hubicka  <jh@suse.cz>
 
-       * Makefile.in (bb-reoder.o): Add depdendency on cfglayout.h;
-       remove unneded depdendencies;
+       * Makefile.in (bb-reoder.o): Add dependency on cfglayout.h;
+       remove unneeded dependencies;
        (cfglayout.o): New.
        * cfglayout.c, cfglayout.h: New files; break out from ...
        * bb-reorder.c: ... here; Remove unneeded includes;
@@ -1935,7 +1945,7 @@ Fri Oct 26 07:18:08 2001  Richard Kenner  <kenner@vlsi1.ultra.nyu.edu>
 
 2001-10-26  Christopher Faylor  <cgf@redhat.com>
 
-       * config/i386/cygwin.h: Search target specfic include directory, if
+       * config/i386/cygwin.h: Search target specific include directory, if
        appropriate.
 
 2001-10-25  Kaveh R. Ghazi  <ghazi@caip.rutgers.edu>
@@ -10303,12 +10313,12 @@ Mon Jul 30 22:16:08 CEST 2001  Jan Hubicka  <jh@suse.cz>
        * alias.c (loop_p): Remove.
        (mark_constant_function): Use mark_dfs_back_edges.
 
-       * reg-stack.c (block_info_def): Add predecesors counter and stack_out.
-       (reg_to_stack): Call mark_dfs_back_edges; count the predecesors.
+       * reg-stack.c (block_info_def): Add predecessors counter and stack_out.
+       (reg_to_stack): Call mark_dfs_back_edges; count the predecessors.
        (compensate_edge): Break out from ...
        (convert_regs_1): ... here; do smart choosing of stack_out to copy.
        (convert_regs_2): Set block_done once block is really done;
-       Do updating of the predecesors counts.
+       Do updating of the predecessors counts.
 
        * toplev.c (rest_of_compilation): Recompute block_for_insn
        before post-reload cfg_cleanup.
@@ -10986,7 +10996,7 @@ Mon Jul 23 16:03:19 CEST 2001  Jan Hubicka  <jh@suse.cz>
        * toplev.c (rest_of_compilation): Conditionally call purge_all_dead_edges
        after combine.
        * gcse.c (cprop_cc0_jump, cprop_insn): New argument "basic_block".
-       (cprop_jump): Likewise; call purge_dead_edges if substitution suceeded.
+       (cprop_jump): Likewise; call purge_dead_edges if substitution succeeded.
 
 2001-07-23  Hans-Peter Nilsson  <hp@bitrange.com>
 
@@ -11040,7 +11050,7 @@ Sun Jul 22 23:28:56 CEST 2001  Jan Hubicka  <jh@suse.cz>
        redirect_edge_and_branch, block_label, forwarder_block_p): Make global.
        (redirect_edge_and_branch_force): Fix copying of lifeness information.
        (block_label): Handle EXIT_BLOCK_PTR by returning NULL.
-       * ifcvt.c (dead_or_predictable): Take BB as an new destionation
+       * ifcvt.c (dead_or_predictable): Take BB as an new destination
        instead of label; update CFG after transformation.
        (find_if_case_1): Update call, use redirect_edge_and_branch_force
        for finishing the transformation; handle even case where ELSE
index 4aaeb0f..cba548e 100644 (file)
@@ -9963,7 +9963,7 @@ Thu Aug 26 19:33:23 1999  Jim Wilson  <wilson@cygnus.com>
        * dwarf2out.c (DWARF2_ASM_LINE_DEBUG_INFO): Add default definition.
        (debug_dwarf): Add DWARF2_ASM_LINE_DEBUG_INFO support.
        (dwarf2out_line, dwarf2out_finish): Likewise.
-       * tm.texi (DWARF2_ASM_LINE_DEBUG_INFO): Add documetation.
+       * tm.texi (DWARF2_ASM_LINE_DEBUG_INFO): Add documentation.
 
 Thu Aug 26 16:10:56 1999  Gavin Romig-Koch  <gavin@cygnus.com>
 
@@ -12356,7 +12356,7 @@ Mon Jul 26 22:52:47 1999  Richard Henderson  <rth@cygnus.com>
        * i960.h (BUILD_VA_LIST_TYPE): New.
        (EXPAND_BUILTIN_VA_START): New.
        (EXPAND_BUILTIN_VA_ARG): New.
-       * i960.md (store_multiple): Use change_address on individul mems.
+       * i960.md (store_multiple): Use change_address on individual mems.
 
 Mon Jul 26 22:43:12 1999  Richard Henderson  <rth@cygnus.com>
 
index 4a92b3b..662e3e0 100644 (file)
@@ -4133,7 +4133,7 @@ Sun May  7 00:54:57 EDT 2000  John Wehle  (john@feith.com)
        (rtx_needs_barrier): Handle COND_EXEC.
        * config/ia64/ia64.h (BRANCH_COST): Define.
        (PREDICATE_CODES): Update.
-       * config/ia64/ia64.md: Docuement used unspec values.
+       * config/ia64/ia64.md: Document used unspec values.
        (attr predicable): New.
        (movxf, movxf_internal): New.
        (extendsfdf2): Don't comment out nop.
@@ -5972,7 +5972,7 @@ Sat Apr 22 22:35:38 MET DST 2000  Jan Hubicka  <jh@suse.cz>
        (diagnostic.h): #include.
        (struct output_buffer): Move into diagnostic.h.
        (get_output_prefix): Rename to output_get_prefix.  Export.
-       (init_output_buffer): Export. Break out.  Ajust intialization.
+       (init_output_buffer): Export. Break out.  Adjust initialization.
        (output_space_left, output_append): Export.
        (output_newline): Rename to output_add_newline.  Export.
        (output_clear): Nullify additional output_buffer fields.
@@ -5991,7 +5991,7 @@ Sat Apr 22 22:35:38 MET DST 2000  Jan Hubicka  <jh@suse.cz>
        (vline_wrapper_message_with_location): Ditto.
        (v_message_with_decl): Ditto.  Adjust call to output_puts
        and get_output_prefix.
-       (default_print_error_function): Adjust buffer intialization.
+       (default_print_error_function): Adjust buffer initialization.
 
 Sat Apr 22 06:45:04 2000  Richard Kenner  <kenner@vlsi1.ultra.nyu.edu>
 
@@ -6390,7 +6390,7 @@ Mon Apr 17 23:35:29 MET DST 2000  Jan Hubicka  <jh@suse.cz>
 
 Mon Apr 17 14:59:36 MET DST 2000  Jan Hubicka  <jh@suse.cz>
 
-       * cse.c (struct check_depdendence_data): New.
+       * cse.c (struct check_dependence_data): New.
        (check_dependence): New function.
        (invalidate): Use check_depdenence.
 
@@ -6407,7 +6407,7 @@ Mon Apr 17 14:59:36 MET DST 2000  Jan Hubicka  <jh@suse.cz>
        message in quotes. Otherwise, IBM's make program treats the '#' as the
        start of a comment and ignores the remainder of the line.
 
-       * c-lex.c (yylex): Change for EBCDIC, lower case characters preceed
+       * c-lex.c (yylex): Change for EBCDIC, lower case characters precede
        upper case.
        * cccp.c (initialize_char_syntax): Allow for holes in EBCDIC.
        * cexp.y (initialize_random_junk): Likewise.
@@ -6420,7 +6420,7 @@ Mon Apr 17 14:59:36 MET DST 2000  Jan Hubicka  <jh@suse.cz>
        (real_hex_to_f): Use it.
        * real.c (CHARMASK): New.
        (etoasc, asctoeg): Use it.
-       (asctoeg): EBCDIC lower case characters preceed upper case.
+       (asctoeg): EBCDIC lower case characters precede upper case.
 
        * i370.c (mvs_add_label): Change spacing for coding conventions.
        * i370.h (ASM_OUTPUT_CASE_LABEL): Change to the data CSECT for the
@@ -7756,7 +7756,7 @@ Fri Apr  7 11:50:54 2000  Jim Wilson  <wilson@cygnus.com>
        (compute_coalesced_reg_partition): New function.
        (coalesce_regs_in_copies): Likewise.
        (coalesce_reg_in_phi): Likewise.
-       (coalesce_regs_in_sucessor_phi_nodes): Likewise.
+       (coalesce_regs_in_successor_phi_nodes): Likewise.
        (for_each_successor_phi): Likewise.
        (rename_context): New struct.
        (rename_block): Use a rename_context with rename_insn_1.  When
@@ -12922,7 +12922,7 @@ Fri Feb 18 20:08:57 2000  Richard Kenner  <kenner@vlsi1.ultra.nyu.edu>
        * function.c (assign_parms): Make thisparm_boundary unsigned.
        * genrecog.c (write_switch): Cast XWINT result to int.
        * lcm.c: Many static fcns and vars now #ifdef OPTIMIZE_MODE_SWITCHING.
-       * mips-tfile.c (init_file): Make two versions of FDR intializer:
+       * mips-tfile.c (init_file): Make two versions of FDR initializer:
        one for MIPS and one for Alpha.
        (get_tag, copy_object): Add casts to avoid warnings.
        * optabs.c (init_one_libfunc): Cast NAME to (char *).
index 36bc937..c655716 100644 (file)
@@ -877,7 +877,7 @@ Fri Dec 15 14:48:37 MET 2000  Jan Hubicka  <jh@suse.cz>
        * genrecog.c (add_to_sequence): Remove special case for
        const_int_operand.
        (maybe_both_true): Return 1 when falling out of sequence when
-       trying to find common possition in the pattern.
+       trying to find common position in the pattern.
 
 Fri Dec 15 14:44:51 MET 2000  Jan Hubicka  <jh@suse.cz>
 
@@ -11026,7 +11026,7 @@ Mon Aug 21 07:41:12 2000  Jeffrey A Law  (law@cygnus.com)
        (lang_diagnostic_starter, lang_diagnostic_finalizer): New objects.
        (error_module_changed, record_last_error_module,
        error_function_changed, record_last_error_function): New functions.
-       (initialize_diagnostics): Default intialize
+       (initialize_diagnostics): Default initialize
        lang_diagnostic_starter, lang_diagnostic_finalizer.
        (init_output_buffer): Tweak.
        (file_name_as_prefix): New function.
index f2e578d..b44afad 100644 (file)
@@ -2325,7 +2325,7 @@ Sat Jun  2 12:23:51 CEST 2001  Jan Hubicka  <jh@suse.cz>
        (and?i splitters): Use ext_register_operands.
        (test?i peep2): Remove ignored constraints.
        * i386.c (ext_register_operand): Check that operand is
-       eighter pseudo or hard or 'Q' register.
+       either pseudo or hard or 'Q' register.
 
 Sat Jun  2 06:53:50 2001  Richard Kenner  <kenner@vlsi1.ultra.nyu.edu>
 
@@ -3324,7 +3324,7 @@ Sat May 19 09:40:45 2001  Denis Chertykov  <denisc@overta.ru>
 Fri May 18 22:42:04 CEST 2001  Jan Hubicka  <jh@suse.cz>
 
        * combine.c (combine_simplify_rtx): Clear op0_mode if simplification
-       suceeded.
+       succeeded.
 
 Fri May 18 07:26:34 2001  Richard Kenner  <kenner@vlsi1.ultra.nyu.edu>
 
@@ -10383,7 +10383,7 @@ Wed Feb 14 10:08:26 CET 2001  Jan Hubicka  <jh@suse.cz>
            DJ Delorie  <dj@redhat.com>
 
        * jump.c (jump_optimize_1): When we delete a conditional jump
-       preceeding a non-conditional jump to effectively the same place,
+       preceding a non-conditional jump to effectively the same place,
        make sure that the combined jump skips any clobber insns between
        the two labels.
 
@@ -12771,7 +12771,7 @@ Fri Jan 12 00:04:00 MET 2001  Jan Hubicka  <jh@suse.cz>
        * i386.c (ix86_comparison_operator, fcmov_comparison_operator,
        put_condition_code): Convert fp comparison codes to integer
        before handling.
-       (ix86_expand_fp_compare): Postnote the fp comparison code converison
+       (ix86_expand_fp_compare): Postnote the fp comparison code conversion
        to final.
 
        * i386.c (unsigned_comparison, no_comparison_operator): Kill.
index 6071e8d..57743df 100644 (file)
--- a/gcc/cfg.c
+++ b/gcc/cfg.c
@@ -33,7 +33,7 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA
         make_edge, make_single_succ_edge, cached_make_edge, remove_edge
         - Low level edge redirection (without updating instruction chain)
             redirect_edge_succ, redirect_edge_succ_nodup, redirect_edge_pred
-     - Dumpipng and debugging
+     - Dumping and debugging
         dump_flow_info, debug_flow_info, dump_edge_info
      - Allocation of AUX fields for basic blocks
         alloc_aux_for_blocks, free_aux_for_blocks, alloc_aux_for_block
@@ -119,7 +119,7 @@ struct basic_block_def entry_exit_blocks[2]
 void debug_flow_info                   PARAMS ((void));
 static void free_edge                  PARAMS ((edge));
 \f
-/* Called once at intialization time.  */
+/* Called once at initialization time.  */
 
 void
 init_flow ()
@@ -319,7 +319,7 @@ make_edge (src, dest, flags)
   return cached_make_edge (NULL, src, dest, flags);
 }
 
-/* Create an edge connecting SRC to DEST and set probability by knowling
+/* Create an edge connecting SRC to DEST and set probability by knowing
    that it is the single edge leaving SRC.  */
 
 edge
@@ -389,7 +389,7 @@ redirect_edge_succ (e, new_succ)
   e->dest = new_succ;
 }
 
-/* Like previous but avoid possible dupplicate edge.  */
+/* Like previous but avoid possible duplicate edge.  */
 
 edge
 redirect_edge_succ_nodup (e, new_succ)
index 7dd51e6..679a6e6 100644 (file)
@@ -210,7 +210,7 @@ need_fake_edge_p (insn)
 
 /* Add fake edges to the function exit for any non constant and non noreturn
    calls, volatile inline assembly in the bitmap of blocks specified by
-   BLOCKS or to the whole CFG if BLOCKS is zero.  Return the nuber of blocks
+   BLOCKS or to the whole CFG if BLOCKS is zero.  Return the number of blocks
    that were split.
 
    The goal is to expose cases in which entering a basic block does not imply
@@ -226,7 +226,7 @@ flow_call_edges_add (blocks)
   basic_block *bbs;
   bool check_last_block = false;
 
-  /* Map bb indicies into basic block pointers since split_block
+  /* Map bb indices into basic block pointers since split_block
      will renumber the basic blocks.  */
 
   bbs = xmalloc (n_basic_blocks * sizeof (*bbs));
@@ -288,7 +288,7 @@ flow_call_edges_add (blocks)
            {
              edge e;
 
-             /* The above condition should be enought to verify that there is
+             /* The above condition should be enough to verify that there is
                 no edge to the exit block in CFG already.  Calling make_edge in
                 such case would make us to mark that edge as fake and remove it
                 later.  */
@@ -338,7 +338,7 @@ find_unreachable_blocks ()
     BASIC_BLOCK (i)->flags &= ~BB_REACHABLE;
 
   /* Add our starting points to the worklist.  Almost always there will
-     be only one.  It isn't inconcievable that we might one day directly
+     be only one.  It isn't inconceivable that we might one day directly
      support Fortran alternate entry points.  */
 
   for (e = ENTRY_BLOCK_PTR->succ; e; e = e->succ_next)
index addd84e..cb781d7 100644 (file)
@@ -24,7 +24,7 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 
    - Unreachable blocks removal
    - Edge forwarding (edge to the forwarder block is forwarded to it's
-     succesor.  Simplification of the branch instruction is performed by
+     successor.  Simplification of the branch instruction is performed by
      underlying infrastructure so branch can be converted to simplejump or
      eliminated).
    - Cross jumping (tail merging)
@@ -176,7 +176,7 @@ try_simplify_condjump (cbranch_block)
 }
 \f
 /* Attempt to forward edges leaving basic block B.
-   Return true if sucessful.  */
+   Return true if successful.  */
 
 static bool
 try_forward_edges (mode, b)
@@ -195,9 +195,9 @@ try_forward_edges (mode, b)
 
       /* Skip complex edges because we don't know how to update them.
 
-         Still handle fallthru edges, as we can suceed to forward fallthru
+         Still handle fallthru edges, as we can succeed to forward fallthru
          edge to the same place as the branch edge of conditional branch
-         and turn conditional branch to an unconditonal branch.  */
+         and turn conditional branch to an unconditional branch.  */
       if (e->flags & EDGE_COMPLEX)
        continue;
 
@@ -205,7 +205,7 @@ try_forward_edges (mode, b)
       counter = 0;
 
       /* Look for the real destination of the jump.
-         Avoid inifinite loop in the infinite empty loop by counting
+         Avoid infinite loop in the infinite empty loop by counting
          up to n_basic_blocks.  */
       while (FORWARDER_BLOCK_P (target)
             && target->succ->dest != EXIT_BLOCK_PTR
@@ -680,7 +680,7 @@ flow_find_cross_jump (mode, bb1, bb2, f1, f2)
     }
 #endif
 
-  /* Include preceeding notes and labels in the cross-jump.  One,
+  /* Include preceding notes and labels in the cross-jump.  One,
      this may bring us to the head of the blocks as requested above.
      Two, it keeps line number notes as matched as may be.  */
   if (ninsns)
index 896eda6..5c2ee08 100644 (file)
@@ -85,7 +85,7 @@ typedef struct
 /* Holds the interesting trailing notes for the function.  */
 static rtx function_tail_eff_head;
 
-/* The scope forst of current function.  */
+/* The scope forest of current function.  */
 static scope_forest_info forest;
 
 static rtx skip_insns_after_block      PARAMS ((basic_block));
index d8b5b4d..cabd2f2 100644 (file)
@@ -559,7 +559,7 @@ flow_loop_level_compute (loop, depth)
 }
 
 /* Compute the loop nesting depth and enclosed loop level for the loop
-   hierarchy tree specfied by LOOPS.  Return the maximum enclosed loop
+   hierarchy tree specified by LOOPS.  Return the maximum enclosed loop
    level.  */
 
 static int
index 5d785ca..20cb122 100644 (file)
@@ -34,7 +34,7 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA
             redirect_edge_and_branch_force, tidy_fallthru_edge, force_nonfallthru
      - Edge splitting and commiting to edges
          split_edge, insert_insn_on_edge, commit_edge_insertions
-     - Dumpipng and debugging
+     - Dumping and debugging
          print_rtl_with_bb, dump_bb, debug_bb, debug_bb_n
      - Consistency checking
          verify_flow_info
@@ -291,7 +291,7 @@ create_basic_block_structure (index, head, end, bb_note)
 }
 
 /* Create new basic block consisting of instructions in between HEAD and
-   END and place it to the BB chain at possition INDEX.
+   END and place it to the BB chain at position INDEX.
    END can be NULL in to create new empty basic block before HEAD.
    Both END and HEAD can be NULL to create basic block at the end of
    INSN chain.  */
@@ -691,7 +691,7 @@ try_redirect_by_replacing_jump (e, target)
        fprintf (rtl_dump_file, "Removing jump %i.\n", INSN_UID (insn));
       fallthru = 1;
 
-      /* Selectivly unlink whole insn chain.  */
+      /* Selectively unlink whole insn chain.  */
       delete_insn_chain (kill_from, PREV_INSN (target->head));
     }
   /* If this already is simplejump, redirect it.  */
@@ -749,9 +749,9 @@ try_redirect_by_replacing_jump (e, target)
 /* Return last loop_beg note appearing after INSN, before start of next
    basic block.  Return INSN if there are no such notes.
 
-   When emmiting jump to redirect an fallthru edge, it should always
+   When emitting jump to redirect an fallthru edge, it should always
    appear after the LOOP_BEG notes, as loop optimizer expect loop to
-   eighter start by fallthru edge or jump following the LOOP_BEG note
+   either start by fallthru edge or jump following the LOOP_BEG note
    jumping to the loop exit test.  */
 
 static rtx
@@ -774,11 +774,11 @@ last_loop_beg_note (insn)
    Don't do that on expense of adding new instructions or reordering
    basic blocks.
 
-   Function can be also called with edge destionation equivalent to the
+   Function can be also called with edge destination equivalent to the
    TARGET.  Then it should try the simplifications and do nothing if
    none is possible.
 
-   Return true if transformation suceeded.  We still return flase in case
+   Return true if transformation succeeded.  We still return false in case
    E already destinated TARGET and we didn't managed to simplify instruction
    stream.  */
 
@@ -958,7 +958,7 @@ force_nonfallthru (e)
 
 /* Redirect edge even at the expense of creating new jump insn or
    basic block.  Return new basic block if created, NULL otherwise.
-   Abort if converison is impossible.  */
+   Abort if conversion is impossible.  */
 
 basic_block
 redirect_edge_and_branch_force (e, target)
@@ -1119,7 +1119,7 @@ split_edge (edge_in)
     abort ();
 
   /* We are going to place the new block in front of edge destination.
-     Avoid existence of fallthru predecesors.  */
+     Avoid existence of fallthru predecessors.  */
   if ((edge_in->flags & EDGE_FALLTHRU) == 0)
     {
       edge e;
@@ -1810,7 +1810,7 @@ verify_flow_info ()
   free (edge_checksum);
 }
 \f
-/* Assume that the preceeding pass has possibly eliminated jump instructions
+/* Assume that the preceding pass has possibly eliminated jump instructions
    or converted the unconditional jumps.  Eliminate the edges from CFG.
    Return true if any edges are eliminated.  */
 
@@ -1928,7 +1928,7 @@ purge_dead_edges (bb)
   return purged;
 }
 
-/* Search all basic blocks for potentionally dead edges and purge them.
+/* Search all basic blocks for potentially dead edges and purge them.
 
    Return true iff some edge has been eliminated.
  */
index 5821dd1..a5d5472 100644 (file)
@@ -264,7 +264,7 @@ static struct path_prefix cmdline_lib_dirs; /* directories specified with -L */
 static struct path_prefix libpath_lib_dirs; /* directories in LIBPATH */
 static struct path_prefix *libpaths[3] = {&cmdline_lib_dirs,
                                          &libpath_lib_dirs, NULL};
-static const char *const libexts[3] = {"a", "so", NULL};  /* possible library extentions */
+static const char *const libexts[3] = {"a", "so", NULL};  /* possible library extensions */
 #endif
 
 static void handler            PARAMS ((int));
@@ -1594,7 +1594,7 @@ collect_execute (prog, argv, redir)
       dup2 (stdout_save, STDOUT_FILENO);
       dup2 (stderr_save, STDERR_FILENO);
 
-      /* Close reponse file.  */
+      /* Close response file.  */
       close (redir_handle);
     }
 
index 8e3c0c5..ee27919 100644 (file)
@@ -622,7 +622,7 @@ combine_instructions (f, nregs)
              rtx link = XEXP (links, 0);
 
              /* If the linked insn has been replaced by a note, then there
-                is no point in persuing this chain any further.  */
+                is no point in pursuing this chain any further.  */
              if (GET_CODE (link) == NOTE)
                break;
 
@@ -953,14 +953,14 @@ can_combine_p (insn, i3, pred, succ, pdest, psrc)
                 We depend here on combinable_i3_pat to reject them.  */
              /* The code below this loop only verifies that the inputs of
                 the SET in INSN do not change.  We call reg_set_between_p
-                to verify that the REG in the USE does not change betweeen
+                to verify that the REG in the USE does not change between
                 I3 and INSN.
                 If the USE in INSN was for a pseudo register, the matching
                 insn pattern will likely match any register; combining this
                 with any other USE would only be safe if we knew that the
                 used registers have identical values, or if there was
                 something to tell them apart, e.g. different modes.  For
-                now, we forgo such compilcated tests and simply disallow
+                now, we forgo such complicated tests and simply disallow
                 combining of USES of pseudo registers with any other USE.  */
              if (GET_CODE (XEXP (elt, 0)) == REG
                  && GET_CODE (PATTERN (i3)) == PARALLEL)
@@ -6143,7 +6143,7 @@ make_extraction (mode, inner, pos, pos_rtx, len,
       rtx temp = gen_rtx_ZERO_EXTEND (pos_mode, pos_rtx);
 
       /* If we know that no extraneous bits are set, and that the high
-        bit is not set, convert extraction to cheaper one - eighter
+        bit is not set, convert extraction to cheaper one - either
         SIGN_EXTENSION or ZERO_EXTENSION, that are equivalent in these
         cases.  */
       if (flag_expensive_optimizations
@@ -6463,7 +6463,7 @@ make_compound_operation (x, in_code)
                                     NULL_RTX, 0);
 
          /* If we have something other than a SUBREG, we might have
-            done an expansion, so rerun outselves.  */
+            done an expansion, so rerun ourselves.  */
          if (GET_CODE (newer) != SUBREG)
            newer = make_compound_operation (newer, in_code);
 
@@ -7234,7 +7234,7 @@ if_then_else_cond (x, ptrue, pfalse)
            }
        }
 
-      /* Similarly for MULT, AND and UMIN, execpt that for these the result
+      /* Similarly for MULT, AND and UMIN, except that for these the result
         is always zero.  */
       if ((STORE_FLAG_VALUE == 1 || STORE_FLAG_VALUE == -1)
          && (code == MULT || code == AND || code == UMIN)
@@ -8549,7 +8549,7 @@ num_sign_bit_copies (x, mode)
        return num_sign_bit_copies (XEXP (x, 0), mode);
 
     case UMOD:
-      /* The result must be <= the scond operand.  */
+      /* The result must be <= the second operand.  */
       return num_sign_bit_copies (XEXP (x, 1), mode);
 
     case DIV:
@@ -11375,7 +11375,7 @@ get_last_value (x)
      it's either a hard register, set more than once, or it's a live
      at the beginning of the function, return 0.
 
-     Because if it's not live at the beginnning of the function then the reg
+     Because if it's not live at the beginning of the function then the reg
      is always set before being used (is never used without being set).
      And, if it's set only once, and it's always set before use, then all
      uses must have the same last value, even if it's not from this basic
index 5f39098..8fa5f3a 100644 (file)
 #undef HAVE_AS_GOTOFF_IN_DATA
 
 /* Define if your assembler supports dwarf2 .file/.loc directives,
-   and preserves file table indicies exactly as given. */
+   and preserves file table indices exactly as given. */
 #undef HAVE_AS_DWARF2_DEBUG_LINE
 
 /* Define 0/1 to force the choice for exception handling model. */
index d838362..156010c 100755 (executable)
@@ -7582,7 +7582,7 @@ elif test x$gcc_cv_as != x -a x"$insn" != x ; then
        if $gcc_cv_as -o conftest.o conftest.s > /dev/null 2>&1 \
           && grep debug_line conftest.o > /dev/null 2>&1 ; then
                # The .debug_line file table must be in the exact order that
-               # we specified the files, since these indicies are also used
+               # we specified the files, since these indices are also used
                # by DW_AT_decl_file.  Approximate this test by testing if
                # the assembler bitches if the same index is assigned twice.
                echo '  .file 1 "foo.s"' > conftest.s
index 91047eb..56edfd7 100644 (file)
@@ -1693,7 +1693,7 @@ elif test x$gcc_cv_as != x -a x"$insn" != x ; then
        if $gcc_cv_as -o conftest.o conftest.s > /dev/null 2>&1 \
           && grep debug_line conftest.o > /dev/null 2>&1 ; then
                # The .debug_line file table must be in the exact order that
-               # we specified the files, since these indicies are also used
+               # we specified the files, since these indices are also used
                # by DW_AT_decl_file.  Approximate this test by testing if
                # the assembler bitches if the same index is assigned twice.
                echo '  .file 1 "foo.s"' > conftest.s
@@ -1710,7 +1710,7 @@ fi
 if test x"$gcc_cv_as_dwarf2_debug_line" = xyes; then
        AC_DEFINE(HAVE_AS_DWARF2_DEBUG_LINE, 1,
 [Define if your assembler supports dwarf2 .file/.loc directives,
-   and preserves file table indicies exactly as given.])
+   and preserves file table indices exactly as given.])
 fi
 AC_MSG_RESULT($gcc_cv_as_dwarf2_debug_line)
 
index b34a93d..99cd9ca 100644 (file)
@@ -482,7 +482,7 @@ conflict_graph_compute (regs, p)
            {
              /* Determine which regs are set in this insn.  Since
                 we're in SSA form, if a reg is set here it isn't set
-                anywhere elso, so this insn is where the reg is born.  */
+                anywhere else, so this insn is where the reg is born.  */
              CLEAR_REG_SET (born);
              note_stores (PATTERN (insn), mark_reg, born);
              AND_REG_SET (born, regs);
index a78eb8f..12fcade 100644 (file)
@@ -10569,7 +10569,7 @@ gen_member_die (type, context_die)
      members of this record or union type, we will also be trying to output
      DIEs to represent the *types* of those members. However the `type'
      function (above) will specifically avoid generating type DIEs for member
-     types *within* the list of member DIEs for this (containing) type execpt
+     types *within* the list of member DIEs for this (containing) type except
      for those types (of members) which are explicitly marked as also being
      members of this (containing) type themselves.  The g++ front- end can
      force any given type to be treated as a member of some other
index d52544e..cc6886d 100644 (file)
@@ -1818,7 +1818,7 @@ output_signed_leb128 (value)
 
        struct s { my_type f; };
 
-   Since we may be stuck here without enought information to do exactly
+   Since we may be stuck here without enough information to do exactly
    what is called for in the Dwarf draft specification, we do the best
    that we can under the circumstances and always use the "plain" integral
    fundamental type codes for int, short, and long types.  That's probably
@@ -4979,7 +4979,7 @@ output_type (type, containing_scope)
           to output DIEs to represent the *types* of those members.
           However the `output_type' function (above) will specifically
           avoid generating type DIEs for member types *within* the list
-          of member DIEs for this (containing) type execpt for those
+          of member DIEs for this (containing) type except for those
           types (of members) which are explicitly marked as also being
           members of this (containing) type themselves.  The g++ front-
           end can force any given type to be treated as a member of some
index e45e71f..1bbc999 100644 (file)
@@ -137,7 +137,7 @@ struct eh_region
     ERT_FIXUP
   } type;
 
-  /* Holds the action to perform based on the preceeding type.  */
+  /* Holds the action to perform based on the preceding type.  */
   union {
     /* A list of catch blocks, a surrounding try block,
        and the label for continuing after a catch.  */
@@ -2014,7 +2014,7 @@ sjlj_assign_call_site_values (dispatch_label, lp_info)
 
      A region receives a dispatch index if it is directly reachable
      and requires in-function processing.  Regions that share post-landing
-     pads may share dispatch indicies.  */
+     pads may share dispatch indices.  */
   /* ??? Post-landing pad sharing doesn't actually happen at the moment
      (see build_post_landing_pads) so we don't bother checking for it.  */
 
@@ -3041,7 +3041,7 @@ expand_eh_return ()
 }
 \f
 /* In the following functions, we represent entries in the action table
-   as 1-based indicies.  Special cases are:
+   as 1-based indices.  Special cases are:
 
         0:     null action record, non-null landing pad; implies cleanups
        -1:     null action record, null landing pad; implies no action
@@ -3098,7 +3098,7 @@ add_action_record (ar_hash, filter, next)
       /* The filter value goes in untouched.  The link to the next
         record is a "self-relative" byte offset, or zero to indicate
         that there is no next record.  So convert the absolute 1 based
-        indicies we've been carrying around into a displacement.  */
+        indices we've been carrying around into a displacement.  */
 
       push_sleb128 (&cfun->eh->action_record_data, filter);
       if (next)
index f44fd31..eac597e 100644 (file)
@@ -998,7 +998,7 @@ compute_alignments ()
 
         We to catch first case, we align frequently executed blocks.
         To catch the second, we align blocks that are executed more frequently
-        than the predecesor and the predecesor is likely to not be executed
+        than the predecessor and the predecessor is likely to not be executed
         when function is called.  */
 
       if (!has_fallthru
index fbe570b..fd5bf32 100644 (file)
@@ -810,7 +810,7 @@ delete_noop_moves (f)
 }
 
 /* Delete any jump tables never referenced.  We can't delete them at the
-   time of removing tablejump insn as they are referenced by the preceeding
+   time of removing tablejump insn as they are referenced by the preceding
    insns computing the destination, so we delay deleting and garbagecollect
    them once life information is computed.  */
 static void
index 101a54b..e3748a2 100644 (file)
@@ -3155,7 +3155,7 @@ simplify_or_tree (exp, pterm, insn_code, insn_index)
   return exp;
 }
 /* Compute approximate cost of the expression.  Used to decide whether
-   expression is cheap enought for inline.  */
+   expression is cheap enough for inline.  */
 static int
 attr_rtx_cost (x)
      rtx x;
index 7f4ac87..36b4a31 100644 (file)
@@ -405,7 +405,7 @@ ggc_allocated_p (p)
   base = &table->table[0];
 #endif
 
-  /* Extract the level 1 and 2 indicies.  */
+  /* Extract the level 1 and 2 indices.  */
   L1 = LOOKUP_L1 (p);
   L2 = LOOKUP_L2 (p);
 
@@ -432,7 +432,7 @@ lookup_page_table_entry(p)
   base = &table->table[0];
 #endif
 
-  /* Extract the level 1 and 2 indicies.  */
+  /* Extract the level 1 and 2 indices.  */
   L1 = LOOKUP_L1 (p);
   L2 = LOOKUP_L2 (p);
 
@@ -467,7 +467,7 @@ found:
   base = &table->table[0];
 #endif
 
-  /* Extract the level 1 and 2 indicies.  */
+  /* Extract the level 1 and 2 indices.  */
   L1 = LOOKUP_L1 (p);
   L2 = LOOKUP_L2 (p);
 
index 63ac3ae..a7f18c0 100644 (file)
@@ -1772,7 +1772,7 @@ delete_related_insns (insn)
                   || GET_CODE (PATTERN (lab_next)) == ADDR_DIFF_VEC))
        {
          /* If we're deleting the tablejump, delete the dispatch table.
-            We may not be able to kill the label immediately preceeding
+            We may not be able to kill the label immediately preceding
             just yet, as it might be referenced in code leading up to
             the tablejump.  */
          delete_related_insns (lab_next);
index 88e5841..a1e6845 100644 (file)
--- a/gcc/lcm.c
+++ b/gcc/lcm.c
@@ -1400,7 +1400,7 @@ optimize_mode_switching (file)
 
   /* Ideally we'd figure out what blocks were affected and start from
      there, but this is enormously complicated by commit_edge_insertions,
-     which would screw up any indicies we'd collected, and also need to
+     which would screw up any indices we'd collected, and also need to
      be involved in the update.  Bail and recompute global life info for
      everything.  */
 
index 4c32ac0..3bfa204 100644 (file)
@@ -368,7 +368,7 @@ estimate_probability (loops_info)
       rtx cond, earliest;
       edge e;
 
-      /* If block has no sucessor, predict all possible paths to
+      /* If block has no successor, predict all possible paths to
          it as improbable, as the block contains a call to a noreturn
         function and thus can be executed only once.  */
       if (bb->succ == NULL && !found_noreturn)
@@ -609,7 +609,7 @@ typedef struct block_info_def
   /* True if block needs to be visited in prop_freqency.  */
   int tovisit:1;
 
-  /* Number of predecesors we need to visit first.  */
+  /* Number of predecessors we need to visit first.  */
   int npredecesors;
 } *block_info;
 
@@ -639,7 +639,7 @@ propagate_freq (head)
   basic_block nextbb;
   int n;
 
-  /* For each basic block we need to visit count number of his predecesors
+  /* For each basic block we need to visit count number of his predecessors
      we need to visit first.  */
   for (n = 0; n < n_basic_blocks; n++)
     {
@@ -800,7 +800,7 @@ expensive_function_p (threshold)
   if (threshold > BB_FREQ_MAX)
     abort ();
 
/* Frequencies are out of range.  This eighter means that function contains
      internal loop executing more than BB_FREQ_MAX times or profile feedback
      is available and function has not been executed at all.  */
   if (ENTRY_BLOCK_PTR->frequency == 0)
index 56f4751..a2412e7 100644 (file)
@@ -197,7 +197,7 @@ typedef struct block_info_def
   struct stack_def stack_out;  /* Output stack configuration.  */
   HARD_REG_SET out_reg_set;    /* Stack regs live on output.  */
   int done;                    /* True if block already converted.  */
-  int predecesors;             /* Number of predecesors that needs
+  int predecesors;             /* Number of predecessors that needs
                                   to be visited.  */
 } *block_info;
 
index ffc80de..c66b1a3 100644 (file)
@@ -5900,7 +5900,7 @@ choose_reload_regs (chain)
             A special case are auto_inc expressions; even if the input is
             inherited, we still need the address for the output.  We can
             recognize them because they have RELOAD_OUT set to RELOAD_IN.
-            If we suceeded removing some reload and we are doing a preliminary
+            If we succeeded removing some reload and we are doing a preliminary
             pass just to remove such reloads, make another pass, since the
             removal of one reload might allow us to inherit another one.  */
          else if (rld[r].in
index 90531f8..eb79fe9 100644 (file)
@@ -884,7 +884,7 @@ set_of_1 (x, pat, data1)
 }
 
 /* Give an INSN, return a SET or CLOBBER expression that does modify PAT
-   (eighter directly or via STRICT_LOW_PART and similar modifiers).  */
+   (either directly or via STRICT_LOW_PART and similar modifiers).  */
 rtx
 set_of (pat, insn)
      rtx pat, insn;
@@ -2859,7 +2859,7 @@ find_first_parameter_load (call_insn, boundary)
 
       /* Our caller needs either ensure that we will find all sets
          (in case code has not been optimized yet), or take care
-         for possible labels in a way by setting boundary to preceeding
+         for possible labels in a way by setting boundary to preceding
          CODE_LABEL.  */
       if (GET_CODE (before) == CODE_LABEL)
        {
index 299314a..19b31a0 100644 (file)
@@ -1056,7 +1056,7 @@ compute_dom_prob_ps (bb)
 
   fst_in_edge = nxt_in_edge = IN_EDGES (BB_TO_BLOCK (bb));
 
-  /* Intialize dom[bb] to '111..1'.  */
+  /* Initialize dom[bb] to '111..1'.  */
   sbitmap_ones (dom[bb]);
 
   do
index 84faf14..5825c55 100644 (file)
@@ -1173,7 +1173,7 @@ lang_independent_options f_options[] =
   {"ssa", &flag_ssa, 1,
    N_("Enable SSA optimizations") },
   {"ssa-ccp", &flag_ssa_ccp, 1,
-   N_("Enable SSA conditonal constant propagation") },
+   N_("Enable SSA conditional constant propagation") },
   {"ssa-dce", &flag_ssa_dce, 1,
    N_("Enable aggressive SSA dead code elimination") },
   {"leading-underscore", &flag_leading_underscore, 1,
@@ -4667,7 +4667,7 @@ toplev_main (argc, argv)
   /* Register the language-independent parameters.  */
   add_params (lang_independent_params, LAST_PARAM);
 
-  /* Perform language-specific options intialization.  */
+  /* Perform language-specific options initialization.  */
   (*lang_hooks.init_options) ();
 
   /* Scan to see what optimization level has been specified.  That will
index ef666de..758d319 100644 (file)
@@ -112,7 +112,7 @@ typedef unsigned char ubyte;
    is located, and what the register lifetimes and stack layout are
    within the function.
 
-   The data structures are defined in the DWARF specfication, although
+   The data structures are defined in the DWARF specification, although
    not in a very readable way (see LITERATURE).
 
    Every time an exception is thrown, the code needs to locate the FDE
@@ -800,7 +800,7 @@ expensive_function_p (threshold)
     abort ();
 
-  /* Frequencies are out of range.  This eighter means that function contains
+  /* Frequencies are out of range.  This either means that function contains
      internal loop executing more than BB_FREQ_MAX times or profile feedback
      is available and function has not been executed at all.  */